@@ -8,7 +8,7 @@ package Tangence::Meta::Class;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our %metas; # cache one per class
 
@@ -170,11 +170,10 @@ sub introspect
    return $ret;
 }
 
-# Keep perl happy; keep Britain tidy
-1;
-
-__END__
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
